@@ -138,20 +138,40 @@ struct _AWallpaperPluginClass
 #define LIVEWP_STOP_LIVEBG_ON_VIEW2 "stop_livebg_on_view2"
 #define LIVEWP_STOP_LIVEBG_ON_VIEW3 "stop_livebg_on_view3"
 #define LIVEWP_STOP_LIVEBG_ON_VIEW4 "stop_livebg_on_view4"
+#define LIVEWP_STOP_LIVEBG_ON_VIEW5 "stop_livebg_on_view5"
+#define LIVEWP_STOP_LIVEBG_ON_VIEW6 "stop_livebg_on_view6"
+#define LIVEWP_STOP_LIVEBG_ON_VIEW7 "stop_livebg_on_view7"
+#define LIVEWP_STOP_LIVEBG_ON_VIEW8 "stop_livebg_on_view8"
+#define LIVEWP_STOP_LIVEBG_ON_VIEW9 "stop_livebg_on_view9"
 #define LIVEWP_PAUSE_LIVEBG_ON_VIEW1 "pause_livebg_on_view1"
 #define LIVEWP_PAUSE_LIVEBG_ON_VIEW2 "pause_livebg_on_view2"
 #define LIVEWP_PAUSE_LIVEBG_ON_VIEW3 "pause_livebg_on_view3"
 #define LIVEWP_PAUSE_LIVEBG_ON_VIEW4 "pause_livebg_on_view4"
+#define LIVEWP_PAUSE_LIVEBG_ON_VIEW5 "pause_livebg_on_view5"
+#define LIVEWP_PAUSE_LIVEBG_ON_VIEW6 "pause_livebg_on_view6"
+#define LIVEWP_PAUSE_LIVEBG_ON_VIEW7 "pause_livebg_on_view7"
+#define LIVEWP_PAUSE_LIVEBG_ON_VIEW8 "pause_livebg_on_view8"
+#define LIVEWP_PAUSE_LIVEBG_ON_VIEW9 "pause_livebg_on_view9"
 #define LIVEWP_PAUSE_LIVEBG_ON_VIEW "pause_livebg_on_view"
 #define LIVEWP_PLAY_LIVEBG_ON_VIEW1 "play_livebg_on_view1"
 #define LIVEWP_PLAY_LIVEBG_ON_VIEW2 "play_livebg_on_view2"
 #define LIVEWP_PLAY_LIVEBG_ON_VIEW3 "play_livebg_on_view3"
 #define LIVEWP_PLAY_LIVEBG_ON_VIEW4 "play_livebg_on_view4"
+#define LIVEWP_PLAY_LIVEBG_ON_VIEW5 "play_livebg_on_view5"
+#define LIVEWP_PLAY_LIVEBG_ON_VIEW6 "play_livebg_on_view6"
+#define LIVEWP_PLAY_LIVEBG_ON_VIEW7 "play_livebg_on_view7"
+#define LIVEWP_PLAY_LIVEBG_ON_VIEW8 "play_livebg_on_view8"
+#define LIVEWP_PLAY_LIVEBG_ON_VIEW9 "play_livebg_on_view9"
 #define LIVEWP_PLAY_LIVEBG_ON_VIEW "play_livebg_on_view"
 #define LIVEWP_ALIVE_LIVEBG_ON_VIEW1 "alive_livebg_on_view1"
 #define LIVEWP_ALIVE_LIVEBG_ON_VIEW2 "alive_livebg_on_view2"
 #define LIVEWP_ALIVE_LIVEBG_ON_VIEW3 "alive_livebg_on_view3"
 #define LIVEWP_ALIVE_LIVEBG_ON_VIEW4 "alive_livebg_on_view4"
+#define LIVEWP_ALIVE_LIVEBG_ON_VIEW5 "alive_livebg_on_view5"
+#define LIVEWP_ALIVE_LIVEBG_ON_VIEW6 "alive_livebg_on_view6"
+#define LIVEWP_ALIVE_LIVEBG_ON_VIEW7 "alive_livebg_on_view7"
+#define LIVEWP_ALIVE_LIVEBG_ON_VIEW8 "alive_livebg_on_view8"
+#define LIVEWP_ALIVE_LIVEBG_ON_VIEW9 "alive_livebg_on_view9"
 
 
 
